@@ -5,13 +5,15 @@
 // Modified by:
 // Created:
 // Copyright:   (c) Stefan Csomor
-// RCS-ID:      $Id: graphics.h 49402 2007-10-24 14:48:10Z VZ $
+// RCS-ID:      $Id: graphics.h 57953 2009-01-09 18:46:48Z SC $
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
 #ifndef _WX_GRAPHICS_H_
 #define _WX_GRAPHICS_H_
 
+#include "wx/defs.h"
+
 #if wxUSE_GRAPHICS_CONTEXT
 
 #include "wx/geometry.h"
@@ -27,6 +29,7 @@ class WXDLLIMPEXP_CORE wxGraphicsRenderer;
 class WXDLLIMPEXP_CORE wxGraphicsPen;
 class WXDLLIMPEXP_CORE wxGraphicsBrush;
 class WXDLLIMPEXP_CORE wxGraphicsFont;
+class WXDLLIMPEXP_CORE wxGraphicsBitmap;
 
 /*
  * notes about the graphics context apis
@@ -61,6 +64,10 @@ class WXDLLIMPEXP_CORE wxGraphicsObject : public wxObject
 {
 public :
     wxGraphicsObject() ;
+#if wxABI_VERSION >= 20810
+    wxGraphicsObject( const wxGraphicsObject& other) : wxObject( other ) {}
+    wxGraphicsObject& operator= (const wxGraphicsObject & other) { Ref(other); return *this;}
+#endif
     wxGraphicsObject( wxGraphicsRenderer* renderer ) ;
     virtual ~wxGraphicsObject() ;
 
@@ -80,6 +87,10 @@ class WXDLLIMPEXP_CORE wxGraphicsPen : public wxGraphicsObject
 {
 public :
     wxGraphicsPen() {}
+#if wxABI_VERSION >= 20810
+    wxGraphicsPen( const wxGraphicsPen& other) : wxGraphicsObject( other ) {}
+    wxGraphicsPen& operator= (const wxGraphicsPen & other) { Ref(other); return *this;}
+#endif
     virtual ~wxGraphicsPen() {}
 private :
     DECLARE_DYNAMIC_CLASS(wxGraphicsPen)
@@ -91,6 +102,10 @@ class WXDLLIMPEXP_CORE wxGraphicsBrush : public wxGraphicsObject
 {
 public :
     wxGraphicsBrush() {}
+#if wxABI_VERSION >= 20810
+    wxGraphicsBrush( const wxGraphicsBrush& other) : wxGraphicsObject( other ) {}
+    wxGraphicsBrush& operator= (const wxGraphicsBrush & other) { Ref(other); return *this;}
+#endif
     virtual ~wxGraphicsBrush() {}
 private :
     DECLARE_DYNAMIC_CLASS(wxGraphicsBrush)
@@ -102,6 +117,10 @@ class WXDLLIMPEXP_CORE wxGraphicsFont : public wxGraphicsObject
 {
 public :
     wxGraphicsFont() {}
+#if wxABI_VERSION >= 20810
+    wxGraphicsFont( const wxGraphicsFont& other) : wxGraphicsObject( other ) {}
+    wxGraphicsFont& operator= (const wxGraphicsFont & other) { Ref(other); return *this;}
+#endif
     virtual ~wxGraphicsFont() {}
 private :
     DECLARE_DYNAMIC_CLASS(wxGraphicsFont)
@@ -109,6 +128,20 @@ private :
 
 extern WXDLLEXPORT_DATA(wxGraphicsFont) wxNullGraphicsFont;
 
+class WXDLLIMPEXP_CORE wxGraphicsBitmap : public wxGraphicsObject
+{
+public :
+    wxGraphicsBitmap() {}
+#if wxABI_VERSION >= 20810
+    wxGraphicsBitmap( const wxGraphicsBitmap& other) : wxGraphicsObject( other ) {}
+    wxGraphicsBitmap& operator= (const wxGraphicsBitmap & other) { Ref(other); return *this;}
+#endif
+    virtual ~wxGraphicsBitmap() {}
+private :
+    DECLARE_DYNAMIC_CLASS(wxGraphicsBitmap)
+} ;
+
+extern WXDLLEXPORT_DATA(wxGraphicsBitmap) wxNullGraphicsBitmap;
 
 class WXDLLIMPEXP_CORE wxGraphicsMatrixData : public wxGraphicsObjectRefData
 {
@@ -169,6 +202,10 @@ class WXDLLIMPEXP_CORE wxGraphicsMatrix : public wxGraphicsObject
 {
 public :
     wxGraphicsMatrix() {}
+#if wxABI_VERSION >= 20810
+    wxGraphicsMatrix( const wxGraphicsMatrix& other) : wxGraphicsObject( other ) {}
+    wxGraphicsMatrix& operator= (const wxGraphicsMatrix & other) { Ref(other); return *this;}
+#endif
 
     virtual ~wxGraphicsMatrix() {}
 
@@ -304,6 +341,10 @@ class WXDLLIMPEXP_CORE wxGraphicsPath : public wxGraphicsObject
 {
 public :
     wxGraphicsPath()  {}
+#if wxABI_VERSION >= 20810
+    wxGraphicsPath( const wxGraphicsPath& other) : wxGraphicsObject( other ) {}
+    wxGraphicsPath& operator= (const wxGraphicsPath & other) { Ref(other); return *this;}
+#endif
     virtual ~wxGraphicsPath() {}
 
     //
@@ -426,6 +467,12 @@ public:
 
     // sets the font
     virtual wxGraphicsFont CreateFont( const wxFont &font , const wxColour &col = *wxBLACK ) const;
+    
+#if wxABI_VERSION >= 20809
+    wxGraphicsBitmap CreateBitmap( const wxBitmap &bitmap ) const;
+#endif
+
+    //virtual wxGraphicsBitmap CreateSubBitmap( const wxGraphicsBitmap &bitmap, wxDouble x, wxDouble y, wxDouble w, wxDouble h  ) const;
 
     // create a 'native' matrix corresponding to these values
     virtual wxGraphicsMatrix CreateMatrix( wxDouble a=1.0, wxDouble b=0.0, wxDouble c=0.0, wxDouble d=1.0,
@@ -525,7 +572,10 @@ public:
     //
     // image support
     //
-
+#if wxABI_VERSION >= 20809
+    void DrawGraphicsBitmap( const wxGraphicsBitmap &bmp, wxDouble x, wxDouble y, wxDouble w, wxDouble h );
+#endif
+    
     virtual void DrawBitmap( const wxBitmap &bmp, wxDouble x, wxDouble y, wxDouble w, wxDouble h ) = 0;
 
     virtual void DrawIcon( const wxIcon &icon, wxDouble x, wxDouble y, wxDouble w, wxDouble h ) = 0;
@@ -582,6 +632,10 @@ class WXDLLIMPEXP_CORE wxGraphicsFigure : public wxGraphicsObject
 {
 public :
     wxGraphicsFigure(wxGraphicsRenderer* renderer) ;
+#if wxABI_VERSION >= 20810
+    wxGraphicsFigure( const wxGraphicsFigure& other) : wxGraphicsObject( other ) {}
+    wxGraphicsFigure& operator= (const wxGraphicsFigure & other) { Ref(other); return *this;}
+#endif
 
     virtual ~wxGraphicsFigure() ;
 
@@ -664,6 +718,10 @@ public :
    // sets the font
     virtual wxGraphicsFont CreateFont( const wxFont &font , const wxColour &col = *wxBLACK ) = 0;
 
+#if wxABI_VERSION >= 20809
+    wxGraphicsBitmap CreateBitmap( const wxBitmap &bmp );
+#endif
+
 private :
     DECLARE_NO_COPY_CLASS(wxGraphicsRenderer)
     DECLARE_ABSTRACT_CLASS(wxGraphicsRenderer)
